{% extends 'admin/change_list.html' %}
{% load i18n %}

{% block filters %}
    <div class="actions">
        <form action="">
            {{ choicesfilter }}
            <button type="button" id="id_choicesfilter">{% trans 'Go' %}</button>
        </form>
    </div>
    {{ block.super }}
{% endblock %}
